// ----------------------------------------------------------------------------
// Projekt       : Analytica AnaGate API
// File          : AnaGateClientAD.hpp
// Author        : Axel Schmidt
// Copyright     : (C) 2004 by Analytica GmbH
// ----------------------------------------------------------------------------
// $Id: AnaGateClientAD.hpp,v 1.5 2008/06/26 07:48:29 tobiashanss Exp $
//
// $Log: AnaGateClientAD.hpp,v $
// Revision 1.5  2008/06/26 07:48:29  tobiashanss
// Separaten Schalter fr das Packing eingefgt (USE_DEFAULT_PACKING).
//
// Revision 1.4  2007/11/12 10:50:21  axelschmidt
// Byte-Alignment
//
// Revision 1.3  2007/05/21 11:42:47  axelschmidt
// standard timeout 500 -> 1000 ms
//
// Revision 1.2  2006/04/05 15:47:45  axelschmidt
// ReadDigitalInput command
//
// Revision 1.1  2006/03/06 15:52:21  axelschmidt
// initial version
//
// ----------------------------------------------------------------------------

#ifndef _ANAGATE_CLIENT_AD_HPP
#define _ANAGATE_CLIENT_AD_HPP

// Includes -------------------------------------------------------------------
#include "AnaGateClient.hpp"

#ifndef USE_DEFAULT_PACKING
// packing mode 1 Byte
#pragma pack(push,1)
#endif

/** Standard communication to an device of the AnaGate A/D series via TCP/IP.
    @author  Axel Schmidt
    @version 1.0
*/
class CAnaGateClientAD : public CAnaGateClient
{
   DECLARE_ANATRACE( CAnaGateClientAD );

public:
   /** Standard construktor. 
      @param nTimeout Standard timeout for send/receive requests (default = infinite ).
   */
   CAnaGateClientAD( int nTimeout = 1000 );

   /** Destructor */
   virtual ~CAnaGateClientAD( void );

   /** Reads data from the AD partner. . 
      @param oADValues  Array with the current value of the integrated A/D converters of the AnaGata AD. 
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
      @remarks The values of all A/D converters are returned, even if the are not used (not connected to an analog input).
   */
   int Read( std::vector<AnaUInt32> & oADValues );

    /** Reads data from digital io register of the AnaGate partner. 
      @param nInputBits   Refererence to the variable that receives the digital input register read.
      @param nOutputBits  Refererence to the variable that receives the digital output register read.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   int ReadDigital( unsigned long & nInputBits, unsigned long & nOutputBits );

    /** Reads data from digital io register of the AnaGate partner. 
      @param nInputBits   Refererence to the variable that receives the digital input register read.
      @param nChgBitsUp   All these bits are set which have changed from 0 to 1 since last #ReadDigital or #ReadDigitalInput command.
      @param nChgBitsDown All these bits are set which have changed from 0 to 1 since last #ReadDigital or #ReadDigitalInput command.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   int ReadDigitalInput( unsigned long & nInputBits, unsigned long & nChgBitsUp, unsigned long & nChgBitsDown );

   /** Writes data to digital io register of the SPI partner. 
      @param nOutputBits  Refererence to the variable that hold the digtial IO output register bits to write.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   int WriteDigital( unsigned long nOutputBits );
};

#ifndef USE_DEFAULT_PACKING
// packing mode back to default
#pragma pack(pop)
#endif

#endif // #ifndef _ANAGATE_CLIENT_AD_HPP










