// ----------------------------------------------------------------------------
// Projekt       : Analytica AnaGate API
// File          : AnaGateClientCANDll.hpp
// Author        : Axel Schmidt
// Copyright     : (C) 2008 by Analytica GmbH
// ----------------------------------------------------------------------------
// $Id: AnaGateClientCANDll.hpp,v 1.2 2008/06/26 07:48:29 tobiashanss Exp $
//
// $Log: AnaGateClientCANDll.hpp,v $
// Revision 1.2  2008/06/26 07:48:29  tobiashanss
// Separaten Schalter fr das Packing eingefgt (USE_DEFAULT_PACKING).
//
// Revision 1.1  2008/01/14 17:03:08  axelschmidt
// Callback-Funktion fr CAN in DLL verlagert
//
// ----------------------------------------------------------------------------

#ifndef _ANAGATE_CLIENT_CAN_DLL_HPP
#define _ANAGATE_CLIENT_CAN_DLL_HPP

// Includes -------------------------------------------------------------------
#include "AnaGateClientCAN.hpp"

#ifndef WIN32
#define WINAPI
#endif
typedef void (WINAPI * CAN_PF_CALLBACK) ( int nID, const char *pcBuf, int nLen, int nFlags, int hHandle );

#ifndef USE_DEFAULT_PACKING
// packing mode 1 Byte
#pragma pack(push,1)
#endif

/** Standard communication to an device of the AnaGate CAN series via TCP/IP with the DLL api.
    @author  Axel Schmidt
    @version 1.0
*/
class CAnaGateClientCANDll : public CAnaGateClientCAN
{
   DECLARE_ANATRACE( CAnaGateClientCANDll );

   public:

   /** Standard construktor. 
      @param nHandle Handle of associated DLL partner.
      @param nTimeout Standard timeout for send/receive requests (default = infinite ).
   */
   CAnaGateClientCANDll( int nHandle, int nTimeout = 1000 );

   /** Destructor */
   virtual ~CAnaGateClientCANDll( void );

   /** Sets the callback function which is called every time a CAN message is received.
      @param pFunction Pointer to the funciton
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   void SetCallback( CAN_PF_CALLBACK pFunction );
   
protected:

   /** This method should be overwritten if the Anagate protocol defines data indications, which 
         has to be responded. In this funcion the respond of the incoming telegram has to be 
         implemented by the derived protocol class.
         @param pMsg  Pointer to the data indication.
         @return true, if message object should not be discarded by base class. 
   */
   virtual bool DataIndRespond( CAnaGateMsg * pMsg );

private:
   CAN_PF_CALLBACK m_pfCBFunction;  ///< Callback function
   int             m_nHandle;       ///< Access handle
};

#ifndef USE_DEFAULT_PACKING
// packing mode back to default
#pragma pack(pop)
#endif

#endif // #ifndef _ANAGATE_CLIENT_CAN_DLL_HPP










