// ----------------------------------------------------------------------------
// Projekt       : Analytica AnaGate API
// File          : AnaGateClientDIO.hpp
// Author        : Axel Schmidt
// Copyright     : (C) 2005 by Analytica GmbH
// ----------------------------------------------------------------------------
// $Id: AnaGateClientDIO.hpp,v 1.5 2008/06/26 07:48:29 tobiashanss Exp $
//
// $Log: AnaGateClientDIO.hpp,v $
// Revision 1.5  2008/06/26 07:48:29  tobiashanss
// Separaten Schalter fr das Packing eingefgt (USE_DEFAULT_PACKING).
//
// Revision 1.4  2007/11/12 10:50:21  axelschmidt
// Byte-Alignment
//
// Revision 1.3  2007/05/21 11:42:47  axelschmidt
// standard timeout 500 -> 1000 ms
//
// Revision 1.2  2005/08/04 11:02:21  axelschmidt
// reads also output register
//
// Revision 1.1  2005/08/04 09:52:04  axelschmidt
// intial
//
// ----------------------------------------------------------------------------

#ifndef _ANAGATE_CLIENT_DIO_HPP
#define _ANAGATE_CLIENT_DIO_HPP

// Includes -------------------------------------------------------------------
#include "AnaGateClient.hpp"

#ifndef USE_DEFAULT_PACKING
// packing mode 1 Byte
#pragma pack(push,1)
#endif

/** Standard communication to an device of the AnaGate DIO series via TCP/IP.
    @author  Axel Schmidt
    @version 1.0
*/
class CAnaGateClientDIO : public CAnaGateClient
{
   DECLARE_ANATRACE( CAnaGateClientDIO );

public:
   /** Standard construktor. 
      @param nTimeout Standard timeout for send/receive requests (default = infinite ).
   */
   CAnaGateClientDIO( int nTimeout = 1000 );

   /** Destructor */
   virtual ~CAnaGateClientDIO( void );

   /** Reads data from digtial io register of the DIO partner. 
      @param nInputBits   Refererence to the variable that receives the digtial input register read.
      @param nOutputBits  Refererence to the variable that receives the digtial output register read.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   int Read( unsigned long & nInputBits, unsigned long & nOutputBits );

   /** Writes data to digital io register of the DIO partner. 
      @param nOutputBits  Refererence to the variable that hold the digtial IO output register bits to write.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   int Write( unsigned long nOutputBits );

protected:
};

#ifndef USE_DEFAULT_PACKING
// packing mode back to default
#pragma pack(pop)
#endif

#endif // #ifndef _ANAGATE_CLIENT_DIO_HPP










