// ----------------------------------------------------------------------------
// Projekt       : Analytica AnaGate API
// File          : AnaGateClientRenesas.hpp
// Author        : Axel Schmidt
// Copyright     : (C) 2007 by Analytica GmbH
// ----------------------------------------------------------------------------
// $Id: AnaGateClientRenesas.hpp,v 1.4 2008/06/26 07:48:29 tobiashanss Exp $
//
// $Log: AnaGateClientRenesas.hpp,v $
// Revision 1.4  2008/06/26 07:48:29  tobiashanss
// Separaten Schalter fr das Packing eingefgt (USE_DEFAULT_PACKING).
//
// Revision 1.3  2007/11/12 10:50:21  axelschmidt
// Byte-Alignment
//
// Revision 1.2  2007/10/25 07:02:35  axelschmidt
// Block-Erase added
//
// Revision 1.1  2007/05/21 11:41:00  axelschmidt
// initial
//
// ----------------------------------------------------------------------------

#ifndef _ANAGATE_CLIENT_RENESAS_HPP
#define _ANAGATE_CLIENT_RENESAS_HPP

// Includes -------------------------------------------------------------------
#include "AnaGateClient.hpp"

#ifndef USE_DEFAULT_PACKING
// packing mode 1 Byte
#pragma pack(push,1)
#endif

/** Standard communication to an device of the AnaGate Renesas series via TCP/IP.
    @author  Axel Schmidt
    @version 1.0
*/
class CAnaGateClientRenesas : public CAnaGateClient
{
   DECLARE_ANATRACE( CAnaGateClientRenesas );

public:

   /** Supported baudrates for Renesas*/
   enum EBaudrate
   {
      B9600       = 0,     ///<   9600
      B19200      = 1,     ///<  19200
      B38400      = 2,     ///<  38400
      B57600      = 3,     ///<  57600
      B115200     = 4      ///< 115200
   };

   /** Standard construktor. 
      @param nTimeout Standard timeout for send/receive requests (default = infinite ).
   */
   CAnaGateClientRenesas( int nTimeout = 1000 );

   /** Destructor */
   virtual ~CAnaGateClientRenesas( void );

   int Init( void );
   int Complete( void );
   int CheckID( const char *pcIDBuffer, int nBufLen );
   int GetVersion(  char *pcBuffer, int nBufLen );
   int SetBaudrate( int nBaudrate );
   int ReadPage( unsigned short nPageAddress, char *pcBuffer, int nNumberOfBytesToRead, int & nNumberOfBytesRead  );
   int WritePage ( unsigned short nPageAddress, const char *pcBuffer, int nNumberOfBytesToWrite );
   int VerifyCheck ( unsigned short nStartAddress, unsigned short nEndAddress, unsigned short & nChecksum );
   int EraseAll( void );
   int BlockErase( unsigned short nPageAddress );

   /** Reads data from digtial io register of the Renesas partner. 
      @param nInputBits   Refererence to the variable that receives the digtial input register read.
      @param nOutputBits  Refererence to the variable that receives the digtial output register read.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   int ReadDigital( unsigned long & nInputBits, unsigned long & nOutputBits );

   /** Writes data to digital io register of the Renesas partner. 
      @param nOutputBits  Refererence to the variable that hold the digtial IO output register bits to write.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   int WriteDigital( unsigned long nOutputBits );
};

#ifndef USE_DEFAULT_PACKING
// packing mode back to default
#pragma pack(pop)
#endif

#endif // #ifndef _ANAGATE_CLIENT_RENESAS_HPP










