// ----------------------------------------------------------------------------
// Projekt       : Analytica AnaGate API
// File          : AnaGateDllDIO.h
// Author        : Axel Schmidt
// Copyright     : (C) 2005 by Analytica GmbH
// ----------------------------------------------------------------------------
// $Id: AnaGateDllDIO.h,v 1.3 2007/05/21 11:43:39 axelschmidt Exp $
//
// $Log: AnaGateDllDIO.h,v $
// Revision 1.3  2007/05/21 11:43:39  axelschmidt
// standard timeout 500 -> 1000 ms
//
// Revision 1.2  2005/08/04 11:02:21  axelschmidt
// reads also output register
//
// Revision 1.1  2005/08/04 09:52:05  axelschmidt
// intial
//
// ----------------------------------------------------------------------------

#ifndef ANAGATE_DLL_DIO_H
#define ANAGATE_DLL_DIO_H

// Defines --------------------------------------------------------------------
#ifdef ANADIODLL_EXPORTS
#define ANADIODLL_API __declspec(dllexport)
#else
#define ANADIODLL_API __declspec(dllimport)
#endif

#include "AnaGateDLL.h"

// Prototyping ----------------------------------------------------------------
extern "C"
{
   /** Opens an AnaGate DIO device.
      @param pHandle Pointer to an integer, in which the device handle is stored, if device is
                     opened successfully.
      @param pcIPAddress Tcp/ip address of the AnaGate device (Port is always 5000).
      @param nTimeout Standard tcp/ip timeout in millseconds.
      @return If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   ANADIODLL_API int  DIOOpenDevice( int *pHandle, const char * pcIPAddress, int nTimeout = 1000 );
   
   /** Closes an open AnaGate DIO device.
       @param hHandle Device handle (from a successfull #OpenDevice call).
       @return If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   ANADIODLL_API int  DIOCloseDevice( int hHandle );

   /** Reads data bits from the DIO partner. 
      @param hHandle  Device handle (from a successfull #OpenDevice call).
      @param nInBits  Holds the current digital input register bits.
      @param nOutBits Holds the current digital output register bits.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   ANADIODLL_API int  DIORead ( int hHandle, unsigned long & nInBits, unsigned long & nOutBits );

   /** Writes data bits to the DIO partner. 
      @param hHandle Device handle (from a successfull #OpenDevice call).
      @param nOutBits Holds the digital output register bist to write.
      @return. If the function succeeds, the return value is zero. If the function fails, the return value is non zero. 
   */
   ANADIODLL_API int  DIOWrite ( int hHandle, unsigned long nOutBits );

   /** Retrieves a textual error description of the supplied return code.
      @param nRC Return code.
      @param pcMessage Pointer to a c-style character buffer, in which the retrieved error string is stored.
      @param nMessageLen Length of the supplied charcter buffer. If the error string does not fit into the
             buffer, the string is shortened.
      @return The byte of the returned error string.
   */
   ANADIODLL_API int  DIOErrorMessage( int nRC, char *pcMessage, int nMessageLen );
}

#endif // ANAGATE_DLL_DIO_H
